@@ -1,5 +1,5 @@
 #from .mvn_kp_3d import mvn_kp_3d
-from .mvn_kp_alt_plot import mvn_kp_alt_plot
+from .mvn_kp_altplot import mvn_kp_altplot
 from .mvn_kp_bin import mvn_kp_bin
 from .mvn_kp_download_files import mvn_kp_download_files
 from .mvn_kp_download_sci_files import mvn_kp_download_sci_files
@@ -7,4 +7,8 @@ from .mvn_kp_plot import mvn_kp_plot
 from .mvn_kp_read import mvn_kp_read
 from .mvn_kp_resample import mvn_kp_resample
 from .mvn_kp_standards import mvn_kp_standards
-from .mvn_kp_map2d import mvn_kp_map2d
\ No newline at end of file
+from .mvn_kp_map2d import mvn_kp_map2d
+from .mvn_kp_read_model_results import mvn_kp_read_model_results
+from .mvn_kp_insitu_search import mvn_kp_insitu_search
+from .mvn_kp_interpol_model import mvn_kp_interpol_model
+from .mvn_kp_create_model_maps import mvn_kp_create_model_maps
\ No newline at end of file
