@@ -690,7 +690,7 @@ def get_values_from_list(the_list, location):
         return testing
     
 def orbit_time(begin_orbit, end_orbit=None):
-    orb_file = os.path.join(os.path.dirname(os.path.dirname(__file__)), 
+    orb_file = os.path.join(os.path.dirname(__file__), 
                             'maven_orb_rec.orb')
     
     f = open(orb_file, "r")
